Installation — plone.jsonapi.routes 0.8.3 documentation

### Navigation

- index
- next |
- previous |
- plone.jsonapi.routes 0.8.3 documentation »

# Installation

This package depends on two external libraries, plone.jsonapi.core and plone.api. The first one is the core framework which takes care of the dispatching of requests and route registration. The latter one is a simplified API to the Plone CMS.

## Buildout

The simplest way to install plone.jsonapi.routes is to add it to the buildout configuration:

    [buildout]

    ...

    [instance]
    ...
    eggs =
        ...
        plone.jsonapi.routes

Run the buildout and your Plone site will become RESTful.

The routes for the standard Plone content types get registered on startup. The following URL should be available after startup:

http://localhost:8080/Plone/@@API/plone/api/1.0

## JSONView

Use the JSONView Plugin for your browser to view the generated JSON in a more comfortable way. You can find the extensions here:

- Firefox: https://addons.mozilla.org/de/firefox/addon/jsonview
- Chrome: https://chrome.google.com/webstore/detail/jsonview/chklaanhfefbnpoihckbnefhakgolnmc?hl=en

## Advanced Rest Client

Use this Chrome Plugin to send POST request to the Plone JSON API. You can find it here:

https://chrome.google.com/webstore/detail/advanced-rest-client/hgmloofddffdnphfgcellkdfbfbjeloo

### Navigation

- index
- next |
- previous |
- plone.jsonapi.routes 0.8.3 documentation »